@@ -2,7 +2,7 @@ package FBP::Project;
 
 use Mouse;
 
-our $VERSION = '0.37';
+our $VERSION = '0.38';
 
 extends 'FBP::Object';
 with    'FBP::Children';
@@ -22,6 +22,16 @@ has internationalize => (
 	isa => 'Bool',
 );
 
+has encoding => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
+has namespace => (
+	is  => 'ro',
+	isa => 'Str',
+);
+
 no Mouse;
 __PACKAGE__->meta->make_immutable;
 
